diff --git a/algo/detectors/rich/ReadoutConfig.cxx b/algo/detectors/rich/ReadoutConfig.cxx
index de19b27b13d82fd7789a3492be1d19a27ca8cb17..5e420242889825c3326574078b6499e2803c0da5 100644
--- a/algo/detectors/rich/ReadoutConfig.cxx
+++ b/algo/detectors/rich/ReadoutConfig.cxx
@@ -65,7 +65,7 @@ namespace cbm::algo::rich
 
     // Constants
     const uint16_t numComp          = 1;   // Number of components
-    const uint16_t numElinksPerComp = 84;  // Number of elinks per component (74 mRICH, 2 FSD/NCAL, 8 PASTA)
+    const uint16_t numElinksPerComp = 87;  // Number of elinks per component (74 mRICH, 5 FSD/NCAL, 8 PASTA)
     const uint16_t numChanPerElink  = 33;  // Number of channels per Elink
 
     // Equipment IDs for each component
@@ -78,8 +78,8 @@ namespace cbm::algo::rich
       0x7130, 0x7131, 0x7140, 0x7141, 0x7150, 0x7151, 0x7160, 0x7161, 0x7170, 0x7171, 0x7180, 0x7181, 0x7200,
       0x7201, 0x7210, 0x7211, 0x7220, 0x7221, 0x7230, 0x7231, 0x7240, 0x7241, 0x7250, 0x7251, 0x7260, 0x7261,
       0x7270, 0x7271, 0x7280, 0x7281, 0x7300, 0x7301, 0x7310, 0x7311, 0x7320, 0x7321, 0x7330, 0x7331, 0x7340,
-      0x7341, 0x7350, 0x7351, 0x7360, 0x7361, 0x7370, 0x7371, 0x7380, 0x7381, 0x7901, 0x7902, 0x9992, 0x9993,
-      0x9994, 0x9995, 0x9996, 0x9997, 0x9998, 0x9999 };
+      0x7341, 0x7350, 0x7351, 0x7360, 0x7361, 0x7370, 0x7371, 0x7380, 0x7381, 0x7901, 0x7902, 0x7903, 0x7904,
+      0x7905, 0x9992, 0x9993, 0x9994, 0x9995, 0x9996, 0x9997, 0x9998, 0x9999 };
     // TRBaddresses 0x7901 and 0x7902 are for FSD/NCAL
     // TRBaddresses 0x9992 to 0x9999 are for PASTA
 
@@ -331,6 +331,15 @@ namespace cbm::algo::rich
       {0.00,  10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00,
        10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00,
        10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00},
+      {0.00,  10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00,
+       10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00,
+       10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00},
+      {0.00,  10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00,
+       10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00,
+       10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00},
+      {0.00,  10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00,
+       10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00,
+       10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00},
       {0.00,  10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00,
        10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00,
        10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00, 10.00}};
diff --git a/macro/beamtime/mcbm2024/mRichPar_70.par b/macro/beamtime/mcbm2024/mRichPar_70.par
index 940949b33d5003f5e12913ef860dd1dff74bfa14..7730723f6053f5ee334cd8ed7494a197051d7533 100644
--- a/macro/beamtime/mcbm2024/mRichPar_70.par
+++ b/macro/beamtime/mcbm2024/mRichPar_70.par
@@ -77,6 +77,9 @@ TRBaddresses: Int_t \
   0x7381  \
   0x7901  \
   0x7902  \
+  0x7903  \
+  0x7904  \
+  0x7905  \
   0x7992  \
   0x7993  \
   0x7994  \
@@ -170,6 +173,9 @@ ToTshifts: Double_t \
   0.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00 \
   0.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00 \
   0.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00 \
+  0.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00 \
+  0.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00 \
+  0.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00 \
   0.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00  10.00
 
 ########################
diff --git a/reco/detectors/rich/mcbm/CbmRichMCbmHitProducer.cxx b/reco/detectors/rich/mcbm/CbmRichMCbmHitProducer.cxx
index 1126b91cc847708f2910d84b6dd0bd511a9d1343..94c9a612e009de9d0b83f53a2ab8e8938991b19b 100644
--- a/reco/detectors/rich/mcbm/CbmRichMCbmHitProducer.cxx
+++ b/reco/detectors/rich/mcbm/CbmRichMCbmHitProducer.cxx
@@ -202,8 +202,8 @@ void CbmRichMCbmHitProducer::ProcessDigi(CbmEvent* event, Int_t digiIndex)
   if (digi == nullptr) return;
   if (digi->GetAddress() < 0) return;
   Int_t DiRICH_Add = (digi->GetAddress() >> 16) & 0xFFFF;
-  if (DiRICH_Add == 0x7901 || DiRICH_Add == 0x7902 || (0x9992 <= DiRICH_Add && DiRICH_Add <= 0x9999)) {
-    // TRBaddresses 0x7901 and 0x7902 are for FSD/NCAL
+  if ((0x7901 <= DiRICH_Add && DiRICH_Add <= 0x7905) || (0x9992 <= DiRICH_Add && DiRICH_Add <= 0x9999)) {
+    // TRBaddresses 0x7901 to 0x7905 are for FSD/NCAL
     // TRBaddresses 0x9992 to 0x9999 are for PASTA
     return;
   }